@@ -1,3 +1,3 @@
-from cms.models.base import PageBase, PublishedBase, PublishedBaseSearchAdapter, SearchMetaBase, OnlineBase, OnlineBaseSearchAdapter, SearchMetaBaseSearchAdapter, PageBaseSearchAdapter
+from cms.models.base import PageBase, PublishedBase, PublishedBaseSearchAdapter, SearchMetaBase, OnlineBase, OnlineBaseSearchAdapter, SearchMetaBaseSearchAdapter, PageBaseSearchAdapter, path_token_generator
 from cms.models.fields import HtmlField, LinkField
 from cms.models.managers import PublicationManagementError, publication_manager, PublishedBaseManager, OnlineBaseManager, SearchMetaBaseManager, PageBaseManager
